@@ -16,7 +16,7 @@ def enter_and_leave_function(func):
             if not result:
                 log.warn(f"finish run function {func.__name__},args is {args},kwargs is {kwargs}, but result is None")
             else:
-                log.info("finish run function {func.__name__}")
+                log.info(f"finish run function {func.__name__}")
             return result
         except Exception as e:
             log.error(f"failed to run functon {func.__name__} error message is : {e}")
